"""Decorators for SDK functions."""
from typing import Any, Callable, Optional


def prompt_confirmation(prompt_text: str) -> Callable:
    """Show prompt asking user whether they want to continue. Exits on anything but y(es)."""

    def outer_wrapper(func: Callable) -> Callable:
        def wrapper(self: Any, force: Optional[bool] = False) -> Optional[Callable]:
            if not force:
                if input(prompt_text).lower() not in ["y", "yes"]:
                    print("Delete cancelled.")
                    return None
                return func(self, force)
            return func(self, force)

        return wrapper

    return outer_wrapper



"""Library defining the interface to continuous testing."""
from datetime import timedelta
from typing import Any, Dict, Iterator, List, Optional

import pandas as pd

from rime_sdk.internal.config_parser import (
    convert_single_data_info_to_swagger,
    convert_single_pred_info_to_swagger,
)
from rime_sdk.internal.constants import (
    MONITOR_TYPE_TO_SWAGGER,
    RISK_CATEGORY_TO_SWAGGER,
)
from rime_sdk.internal.decorators import prompt_confirmation
from rime_sdk.internal.rest_error_handler import RESTErrorHandler
from rime_sdk.internal.swagger_parser import parse_events_to_df
from rime_sdk.internal.swagger_utils import rest_to_timedelta
from rime_sdk.internal.throttle_queue import ThrottleQueue
from rime_sdk.internal.utils import convert_dict_to_html, make_link
from rime_sdk.job import ContinuousTestJob
from rime_sdk.monitor import Monitor
from rime_sdk.registry import Registry
from rime_sdk.swagger import swagger_client
from rime_sdk.swagger.swagger_client import (
    ApiClient,
    ContinuoustestsFirewallIdUuidBody,
    FirewallFirewall,
    FirewallFirewallFirewallIdUuidBody,
    FirewallScheduledCTInfo,
    RimeUUID,
    RuntimeinfoCustomImage,
    RuntimeinfoCustomImageType,
    RuntimeinfoResourceRequest,
    RuntimeinfoRunTimeInfo,
    TestrunTestRunIncrementalConfig,
    V1firewallfirewallFirewallIdUuidFirewall,
)
from rime_sdk.swagger.swagger_client.api.detection_api import DetectionApi
from rime_sdk.swagger.swagger_client.models import RimeJobMetadata
from rime_sdk.swagger.swagger_client.models.detection_event_type import (
    DetectionEventType,
)


class ContinuousTest:
    """An interface to RIME continuous testing."""

    # A throttler that limits the number of model tests to roughly 20 every 5 minutes.
    # This is a static variable for Client.
    _throttler = ThrottleQueue(desired_events_per_epoch=20, epoch_duration_sec=300)

    def __init__(self, api_client: ApiClient, ct_id: str) -> None:
        """Create a new continuous testing object.

        Arguments:
            api_client: ApiClient
                The client used to query the RIME cluster.
            ct_id: str
                The ID of the continuous testing object.
        """
        self._api_client = api_client
        self._ct_id = ct_id

    def __eq__(self, obj: Any) -> bool:
        """Check if this CTInstance is equivalent to 'obj'."""
        return isinstance(obj, ContinuousTest) and self._ct_id == obj._ct_id

    def __repr__(self) -> str:
        """Return string representation of the object."""
        return f"ContinuousTest({self._ct_id})"

    def update_ct(
        self,
        model_id: Optional[str] = None,
        ref_data_id: Optional[str] = None,
        scheduled_ct_eval_data_integration_id: Optional[str] = None,
        scheduled_ct_eval_data_info: Optional[dict] = None,
        scheduled_ct_eval_pred_integration_id: Optional[str] = None,
        scheduled_ct_eval_pred_info: Optional[dict] = None,
        disable_scheduled_ct: Optional[bool] = False,
    ) -> Dict:
        """Update the ContinuousTest with specified model and reference data.

        Arguments:
            model_id: Optional[str]
                The ID of the model to use for the ContinuousTest.
            ref_data_id: Optional[str]
                The ID of the reference data to use for the ContinuousTest.
            scheduled_ct_eval_data_integration_id: Optional[str]
                The integration id of the evaluation data for scheduled CT.
            scheduled_ct_eval_data_info: Optional[Dict]
                The data info of the evaluation data for scheduled CT.
            scheduled_ct_eval_pred_integration_id: Optional[str]
                The integration id of the evaluation prediction for scheduled CT.
            scheduled_ct_eval_pred_info: Optional[Dict]
                The data info of the evaluation prediction for scheduled CT.
            disable_scheduled_ct: Optional[bool]
                Specifies whether to disable continuous testing

        Returns:
            Dict:
                Dictionary representation of updated ContinuousTest object.

        Raises:
            ValueError
                This error is generated when no fields are submitted to be updated or
                when the request to the continuous testing service fails.

        Example:
            .. code-block:: python

                response = ct.update_ct(ref_data_id="New reference data ID")
        """
        api = swagger_client.FirewallServiceApi(self._api_client)
        field_mask_list = []
        if model_id is not None:
            field_mask_list.append("modelId")
        if ref_data_id is not None:
            field_mask_list.append("refDataId")
        scheduled_ct_info = FirewallScheduledCTInfo()
        if scheduled_ct_eval_data_integration_id is not None:
            field_mask_list.append("scheduledCtInfo.evalDataIntegrationId")
            scheduled_ct_info.eval_data_integration_id = RimeUUID(
                uuid=scheduled_ct_eval_data_integration_id
            )
        if scheduled_ct_eval_data_info is not None:
            field_mask_list.append("scheduledCtInfo.evalDataInfo")
            scheduled_ct_info.eval_data_info = convert_single_data_info_to_swagger(
                scheduled_ct_eval_data_info
            )
        if scheduled_ct_eval_pred_integration_id is not None:
            field_mask_list.append("scheduledCtInfo.evalPredIntegrationId")
            scheduled_ct_info.eval_pred_integration_id = RimeUUID(
                uuid=scheduled_ct_eval_pred_integration_id
            )
        if scheduled_ct_eval_pred_info is not None:
            field_mask_list.append("scheduledCtInfo.evalPredInfo")
            scheduled_ct_info.eval_pred_info = convert_single_pred_info_to_swagger(
                scheduled_ct_eval_pred_info
            )
        if disable_scheduled_ct:
            field_mask_list.append("scheduledCtInfo.disableScheduledCt")
            scheduled_ct_info.disable_scheduled_ct = disable_scheduled_ct
        if len(field_mask_list) == 0:
            raise ValueError(
                "User must provide at least one of model_id, ref_data_id, "
                "or scheduled CT paramaters."
            )
        req = FirewallFirewallFirewallIdUuidBody(
            firewall_id=RimeUUID(self._ct_id),
            firewall=V1firewallfirewallFirewallIdUuidFirewall(
                model_id=RimeUUID(model_id) if model_id is not None else None,
                ref_data_id=ref_data_id,
                scheduled_ct_info=scheduled_ct_info,
            ),
            mask=",".join(field_mask_list),
        )
        with RESTErrorHandler():
            resp = api.firewall_service_update_firewall(
                firewall_firewall_id_uuid=self._ct_id,
                body=req,
            )
        print(f"ContinuousTest {self._ct_id} updated successfully.")
        return resp.to_dict()

    def activate_ct_scheduling(
        self,
        data_info: dict,
        data_integration_id: Optional[str] = None,
        pred_integration_id: Optional[str] = None,
        pred_info: Optional[dict] = None,
    ) -> None:
        """Activate scheduled CT.

        Arguments:
            data_info: dict
                The data info of the evaluation data for scheduled CT.
            data_integration_id: Optional[str]
                The integration id of the evaluation data for scheduled CT.
            pred_integration_id: Optional[str]
                The integration id of the evaluation prediction for scheduled CT.
            pred_info: Optional[dict]
                The prediction info of the evaluation data for scheduled CT.
        """
        if self.is_scheduled_ct_enabled():
            raise ValueError(
                "Scheduled CT is already enabled. Please use "
                "`update_scheduled_ct_info` to update the location info."
            )
        self.update_ct(
            scheduled_ct_eval_data_integration_id=data_integration_id,
            scheduled_ct_eval_data_info=data_info,
            scheduled_ct_eval_pred_integration_id=pred_integration_id,
            scheduled_ct_eval_pred_info=pred_info,
            disable_scheduled_ct=False,
        )
        print(f"Scheduled CT for {self._ct_id} activated successfully.")

    def update_scheduled_ct_info(
        self,
        data_integration_id: Optional[str] = None,
        data_info: Optional[dict] = None,
        pred_integration_id: Optional[str] = None,
        pred_info: Optional[dict] = None,
    ) -> None:
        """Update scheduled CT.

        Arguments:
            data_integration_id: Optional[str]
                If `data_integration_id` is not `None`, it will be used for for
                scheduled CT.
            data_info: Optional[dict]
                If `data_info` is not `None`, it will be used for scheduled CT.
            pred_integration_id: Optional[str]
                If `pred_integration_id` is not `None`, it will be used for for
                scheduled CT.
            pred_info: Optional[dict]
                If `pred_info` is not `None`, it will be used for scheduled CT.
        """
        self.update_ct(
            scheduled_ct_eval_data_integration_id=data_integration_id,
            scheduled_ct_eval_data_info=data_info,
            scheduled_ct_eval_pred_integration_id=pred_integration_id,
            scheduled_ct_eval_pred_info=pred_info,
        )
        print(f"Location info of ContinuousTest {self._ct_id} updated successfully.")

    def deactivate_ct_scheduling(self) -> None:
        """Deactivate scheduled CT."""
        if not self.is_scheduled_ct_enabled():
            raise ValueError("Scheduled CT is already disabled.")
        self.update_ct(disable_scheduled_ct=True)
        print(f"Scheduled CT for {self._ct_id} deactivated successfully.")

    def _repr_html_(self) -> str:
        """Return HTML representation of the object."""
        info = {
            "ContinuousTest ID": self._ct_id,
            "Link": make_link(
                "https://" + self.get_link(),
                link_text="Continuous Testing Overview Page",
            ),
        }
        return convert_dict_to_html(info)

    def get_link(self) -> str:
        """Return a URL to the ContinuousTest."""
        api = swagger_client.FirewallServiceApi(self._api_client)
        with RESTErrorHandler():
            resp = api.firewall_service_get_url(
                firewall_id_uuid=self._ct_id,
            )
        return resp.url.url

    def get_bin_size(self) -> timedelta:
        """Return the bin size of this ContinuousTest."""
        continuous_test = self._get_continuous_test()
        return rest_to_timedelta(continuous_test.bin_size)

    def get_ref_data_id(self) -> str:
        """Return the ID of the Continuous Test's current reference set."""
        continuous_test = self._get_continuous_test()
        return continuous_test.ref_data_id

    def get_model_id(self) -> str:
        """Return the ID of the ContinuousTest's current model."""
        continuous_test = self._get_continuous_test()
        return continuous_test.model_id.uuid

    def get_scheduled_ct_info(self) -> Optional[Dict]:
        """Return the scheduled continuous testing info of this ContinuousTest as a dict."""
        scheduled_ct_info = self._get_continuous_test().scheduled_ct_info
        if scheduled_ct_info is not None:
            return scheduled_ct_info.to_dict()
        else:
            return None

    def is_scheduled_ct_enabled(self) -> bool:
        """Return whether scheduled continuous testing is enabled for this ContinuousTest."""
        continuous_test = self._get_continuous_test()
        is_enabled = continuous_test.scheduled_ct_info is not None
        is_enabled = (
            is_enabled and not continuous_test.scheduled_ct_info.disable_scheduled_ct
        )
        return is_enabled

    @property
    def project_id(self) -> str:
        """Return the ID of the parent project for this ContinuousTest."""
        ct = self._get_continuous_test()
        return ct.project_id.uuid

    @prompt_confirmation("Are you sure you want to delete this ContinuousTest? (y/n) ")
    def delete_ct(
        self,
        force: Optional[bool] = False,  # noqa: ARG002 (unused-method-argument)
    ) -> None:
        """Delete ContinuousTest.

        Args:
            force: Optional[bool] = False
                When set to True, the ContinuousTest will be deleted immediately. By default,
                a confirmation is required.
        """
        api = swagger_client.FirewallServiceApi(self._api_client)
        with RESTErrorHandler():
            api.firewall_service_delete_firewall(firewall_id_uuid=self._ct_id)
        print("ContinuousTest successfully deleted.")

    def _get_continuous_test(self) -> FirewallFirewall:
        api = swagger_client.FirewallServiceApi(self._api_client)
        with RESTErrorHandler():
            res = api.firewall_service_get_firewall(firewall_id_uuid=self._ct_id)
        return res.firewall

    def get_events_df(
        self,
    ) -> pd.DataFrame:
        """Get a dataframe of Detected Events for the given ContinuousTest.

        Monitors detect Events when degradations occur.
        For example, a Monitor for the metric "Accuracy" will detect an Event
        when the value of the model performance metric drops below a threshold.
        """
        detection_api = DetectionApi(self._api_client)
        next_page_token = ""
        has_more = True
        all_events = []
        while has_more:
            kwargs: Dict[str, Any] = {}
            if len(next_page_token) > 0:
                kwargs["page_token"] = next_page_token
            else:
                # Restrict to events for CT.
                kwargs["first_page_req_event_types"] = [
                    DetectionEventType.METRIC_DEGRADATION,
                    DetectionEventType.SECURITY,
                ]
            with RESTErrorHandler():
                res = detection_api.detection_list_detection_events(
                    self.project_id, **kwargs
                )
                next_page_token = res.next_page_token
                has_more = res.has_more
                all_events += res.events
        df = parse_events_to_df(all_events)
        return df

    def list_monitors(
        self,
        monitor_types: Optional[List[str]] = None,
        risk_category_types: Optional[List[str]] = None,
    ) -> Iterator[Monitor]:
        """List Monitors for this ContinuousTest.

        Monitors examine time-sequenced data in RIME. Built-in Monitors track model
        health metrics such as degradations in model performance metrics or attacks
        on your model. This method can optionally filter by Monitor types or Risk
        Category types.

        Arguments:
            monitor_types: Optional[List[str]]
                Modifies query to return the set of built-in monitors or
                user-created custom monitors.
                Accepted values: ["Default", "Custom"]
            risk_category_types: Optional[List[str]]
                Modifies query to return monitors pertaining to certain categories
                of AI Risk. For instance, monitors that track model performance help
                you track down Operational Risk.
                Accepted values: \
                ["Operational", "Bias_and_Fairness", "Security", "Custom"]

        Returns:
            Iterator[Monitor]:
                A generator of Monitor objects.

        Raises:
            ValueError
                This error is generated when unrecognized filtering parameters are
                provided or when the request to the service fails.

        Example:
            .. code-block:: python

                # List all default Monitors
                monitors = ct.list_monitors(monitor_types=["Default"])
                # For each Monitor, list all detected Events.
                all_events = [monitor.list_detected_events() for monitor in monitors]
        """
        swagger_monitor_types = []
        swagger_risk_types = []
        if monitor_types is not None:
            try:
                swagger_monitor_types = [
                    MONITOR_TYPE_TO_SWAGGER[m] for m in monitor_types
                ]
            except KeyError as e:
                raise ValueError(
                    f"{e.args[0]} is not a valid monitor type,"
                    + f" {list(MONITOR_TYPE_TO_SWAGGER.keys())}"
                    + " are the accepted monitor types."
                )
        if risk_category_types is not None:
            try:
                swagger_risk_types = [
                    RISK_CATEGORY_TO_SWAGGER[r] for r in risk_category_types
                ]
            except KeyError as e:
                raise ValueError(
                    f"{e.args[0]} is not a valid risk category type,"
                    + f" {list(RISK_CATEGORY_TO_SWAGGER.keys())}"
                    + " are the accepted risk category types."
                )
        project_id = self._get_continuous_test().project_id.uuid
        api = swagger_client.MonitorServiceApi(self._api_client)
        next_page_token = ""
        has_more = True
        while has_more:
            kwargs: Dict[str, Any] = {}
            if len(next_page_token) > 0:
                kwargs["page_token"] = next_page_token
            else:
                kwargs["first_page_req_included_monitor_types"] = swagger_monitor_types
                kwargs[
                    "first_page_req_included_risk_category_types"
                ] = swagger_risk_types
            with RESTErrorHandler():
                res = api.monitor_service_list_monitors(
                    firewall_id_uuid=self._ct_id,
                    **kwargs,
                )
            for monitor in res.monitors:
                yield Monitor(
                    self._api_client, monitor.id.uuid, self._ct_id, project_id
                )
            next_page_token = res.next_page_token
            has_more = res.has_more

    def start_continuous_test(
        self,
        eval_data_id: str,
        override_existing_bins: bool = False,
        agent_id: Optional[str] = None,
        ram_request_megabytes: Optional[int] = None,
        cpu_request_millicores: Optional[int] = None,
        random_seed: Optional[int] = None,
        rime_managed_image: Optional[str] = None,
        custom_image: Optional[RuntimeinfoCustomImage] = None,
        **exp_fields: Dict[str, object],
    ) -> ContinuousTestJob:
        """Start a Continuous Testing run.

        Runs a Continuous Testing job on a batch of data.

        Arguments:
            eval_data_id: str
                ID of the evaluation data.
            override_existing_bins: bool
                Specifies whether to override existing bins.
            ram_request_megabytes: Optional[int]
                Megabytes of RAM set as the Kubernetes pod limit for the Stress Test
                Job. The default is 4000MB.
            cpu_request_millicores: Optional[int]
                Millicores of CPU set as the Kubernetes pod limit for the Stress Test
                Job. The default is 1500mi.
            random_seed: Optional[int]
                Random seed to use for the Job, so that Test Job result will be
                deterministic.
            agent_id: Optional[str]
                ID for the Agent where the Continuous Test will be run.
                Uses the default Agent for the workspace when not specified.
            rime_managed_image: Optional[str]
                Name of a Managed Image to use when running the model test.
                The image must have all dependencies required by your model. To create
                new Managed Images with your desired dependencies, use the client's
                `create_managed_image()` method.
            custom_image: Optional[RuntimeinfoCustomImage]
                Specification of a customized container image to use running the model
                test. The image must have all dependencies required by your model.
                The image must specify a name for the image and optionally a pull secret
                (of type RuntimeinfoCustomImagePullSecret) with the name of the
                kubernetes pull secret used to access the given image.
            exp_fields: Dict[str, object]
                Fields for experimental features.

        Returns:
            ContinuousTestJob:
                A ``Job`` object corresponding to the model Continuous Test Job.

        Raises:
            ValueError
                This error is generated when the request to the ModelTesting service
                fails.

        Example:
            .. code-block:: python

                ct = project.get_ct()
                eval_data_id = client.register_dataset("example dataset", data_config)
                job = ct.start_continuous_test(
                    eval_data_id=eval_data_id,
                    ram_request_megabytes=8000,
                    cpu_request_millicores=2000,
                )
        """
        if ram_request_megabytes is not None and ram_request_megabytes <= 0:
            raise ValueError(
                "The requested number of megabytes of RAM must be positive"
            )

        if cpu_request_millicores is not None and cpu_request_millicores <= 0:
            raise ValueError(
                "The requested number of millicores of CPU must be positive"
            )
        registry = Registry(self._api_client)
        resp = registry.get_dataset(dataset_id=eval_data_id)
        registry.log_registry_validation(resp, "eval dataset", eval_data_id)

        req = ContinuoustestsFirewallIdUuidBody(
            test_run_incremental_config=TestrunTestRunIncrementalConfig(
                eval_dataset_id=eval_data_id,
                run_time_info=RuntimeinfoRunTimeInfo(
                    resource_request=RuntimeinfoResourceRequest(
                        ram_request_megabytes=ram_request_megabytes,
                        cpu_request_millicores=cpu_request_millicores,
                    ),
                    random_seed=random_seed,
                ),
            ),
            override_existing_bins=override_existing_bins,
            experimental_fields=exp_fields if exp_fields else None,
            agent_id=RimeUUID(agent_id) if agent_id else None,
        )
        if custom_image:
            req.test_run_incremental_config.run_time_info.custom_image = (
                RuntimeinfoCustomImageType(custom_image=custom_image)
            )
        if rime_managed_image:
            req.test_run_incremental_config.run_time_info.custom_image = (
                RuntimeinfoCustomImageType(managed_image_name=rime_managed_image)
            )
        with RESTErrorHandler():
            ContinuousTest._throttler.throttle(
                throttling_msg="Your request is throttled to limit # of model tests."
            )
            api = swagger_client.ModelTestingApi(self._api_client)
            job: RimeJobMetadata = api.model_testing_start_continuous_test(
                body=req,
                firewall_id_uuid=self._ct_id,
            ).job
        return ContinuousTestJob(self._api_client, job.job_id)



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TestrunresultTestBatchResultDisplay(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'summary_details': 'str',
        'table_columns_to_show': 'list[RimeTableColumn]',
        'long_description_tabs': 'list[RimeLongDescriptionTab]',
        'description_html': 'str'
    }

    attribute_map = {
        'summary_details': 'summaryDetails',
        'table_columns_to_show': 'tableColumnsToShow',
        'long_description_tabs': 'longDescriptionTabs',
        'description_html': 'descriptionHtml'
    }

    def __init__(self, summary_details=None, table_columns_to_show=None, long_description_tabs=None, description_html=None):  # noqa: E501
        """TestrunresultTestBatchResultDisplay - a model defined in Swagger"""  # noqa: E501
        self._summary_details = None
        self._table_columns_to_show = None
        self._long_description_tabs = None
        self._description_html = None
        self.discriminator = None
        if summary_details is not None:
            self.summary_details = summary_details
        if table_columns_to_show is not None:
            self.table_columns_to_show = table_columns_to_show
        if long_description_tabs is not None:
            self.long_description_tabs = long_description_tabs
        if description_html is not None:
            self.description_html = description_html

    @property
    def summary_details(self):
        """Gets the summary_details of this TestrunresultTestBatchResultDisplay.  # noqa: E501

        Summary details are marshalled JSON, the field is not used and is empty.  # noqa: E501

        :return: The summary_details of this TestrunresultTestBatchResultDisplay.  # noqa: E501
        :rtype: str
        """
        return self._summary_details

    @summary_details.setter
    def summary_details(self, summary_details):
        """Sets the summary_details of this TestrunresultTestBatchResultDisplay.

        Summary details are marshalled JSON, the field is not used and is empty.  # noqa: E501

        :param summary_details: The summary_details of this TestrunresultTestBatchResultDisplay.  # noqa: E501
        :type: str
        """

        self._summary_details = summary_details

    @property
    def table_columns_to_show(self):
        """Gets the table_columns_to_show of this TestrunresultTestBatchResultDisplay.  # noqa: E501


        :return: The table_columns_to_show of this TestrunresultTestBatchResultDisplay.  # noqa: E501
        :rtype: list[RimeTableColumn]
        """
        return self._table_columns_to_show

    @table_columns_to_show.setter
    def table_columns_to_show(self, table_columns_to_show):
        """Sets the table_columns_to_show of this TestrunresultTestBatchResultDisplay.


        :param table_columns_to_show: The table_columns_to_show of this TestrunresultTestBatchResultDisplay.  # noqa: E501
        :type: list[RimeTableColumn]
        """

        self._table_columns_to_show = table_columns_to_show

    @property
    def long_description_tabs(self):
        """Gets the long_description_tabs of this TestrunresultTestBatchResultDisplay.  # noqa: E501

        More detailed information about the test batch.  # noqa: E501

        :return: The long_description_tabs of this TestrunresultTestBatchResultDisplay.  # noqa: E501
        :rtype: list[RimeLongDescriptionTab]
        """
        return self._long_description_tabs

    @long_description_tabs.setter
    def long_description_tabs(self, long_description_tabs):
        """Sets the long_description_tabs of this TestrunresultTestBatchResultDisplay.

        More detailed information about the test batch.  # noqa: E501

        :param long_description_tabs: The long_description_tabs of this TestrunresultTestBatchResultDisplay.  # noqa: E501
        :type: list[RimeLongDescriptionTab]
        """

        self._long_description_tabs = long_description_tabs

    @property
    def description_html(self):
        """Gets the description_html of this TestrunresultTestBatchResultDisplay.  # noqa: E501

        Description of the test batch result that may contain HTML.  # noqa: E501

        :return: The description_html of this TestrunresultTestBatchResultDisplay.  # noqa: E501
        :rtype: str
        """
        return self._description_html

    @description_html.setter
    def description_html(self, description_html):
        """Sets the description_html of this TestrunresultTestBatchResultDisplay.

        Description of the test batch result that may contain HTML.  # noqa: E501

        :param description_html: The description_html of this TestrunresultTestBatchResultDisplay.  # noqa: E501
        :type: str
        """

        self._description_html = description_html

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TestrunresultTestBatchResultDisplay, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TestrunresultTestBatchResultDisplay):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeUserRole(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'subject_type': 'RimeSubjectType',
        'subject_id': 'str',
        'role': 'RimeActorRole',
        'implicit_grant': 'bool'
    }

    attribute_map = {
        'subject_type': 'subjectType',
        'subject_id': 'subjectId',
        'role': 'role',
        'implicit_grant': 'implicitGrant'
    }

    def __init__(self, subject_type=None, subject_id=None, role=None, implicit_grant=None):  # noqa: E501
        """RimeUserRole - a model defined in Swagger"""  # noqa: E501
        self._subject_type = None
        self._subject_id = None
        self._role = None
        self._implicit_grant = None
        self.discriminator = None
        if subject_type is not None:
            self.subject_type = subject_type
        if subject_id is not None:
            self.subject_id = subject_id
        if role is not None:
            self.role = role
        if implicit_grant is not None:
            self.implicit_grant = implicit_grant

    @property
    def subject_type(self):
        """Gets the subject_type of this RimeUserRole.  # noqa: E501


        :return: The subject_type of this RimeUserRole.  # noqa: E501
        :rtype: RimeSubjectType
        """
        return self._subject_type

    @subject_type.setter
    def subject_type(self, subject_type):
        """Sets the subject_type of this RimeUserRole.


        :param subject_type: The subject_type of this RimeUserRole.  # noqa: E501
        :type: RimeSubjectType
        """

        self._subject_type = subject_type

    @property
    def subject_id(self):
        """Gets the subject_id of this RimeUserRole.  # noqa: E501


        :return: The subject_id of this RimeUserRole.  # noqa: E501
        :rtype: str
        """
        return self._subject_id

    @subject_id.setter
    def subject_id(self, subject_id):
        """Sets the subject_id of this RimeUserRole.


        :param subject_id: The subject_id of this RimeUserRole.  # noqa: E501
        :type: str
        """

        self._subject_id = subject_id

    @property
    def role(self):
        """Gets the role of this RimeUserRole.  # noqa: E501


        :return: The role of this RimeUserRole.  # noqa: E501
        :rtype: RimeActorRole
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this RimeUserRole.


        :param role: The role of this RimeUserRole.  # noqa: E501
        :type: RimeActorRole
        """

        self._role = role

    @property
    def implicit_grant(self):
        """Gets the implicit_grant of this RimeUserRole.  # noqa: E501


        :return: The implicit_grant of this RimeUserRole.  # noqa: E501
        :rtype: bool
        """
        return self._implicit_grant

    @implicit_grant.setter
    def implicit_grant(self, implicit_grant):
        """Sets the implicit_grant of this RimeUserRole.


        :param implicit_grant: The implicit_grant of this RimeUserRole.  # noqa: E501
        :type: bool
        """

        self._implicit_grant = implicit_grant

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeUserRole, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeUserRole):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from rime_sdk.swagger.swagger_client.api_client import ApiClient


class ScheduleServiceApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def schedule_service_create_schedule(self, body, **kwargs):  # noqa: E501
        """CreateSchedule creates a schedule.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.schedule_service_create_schedule(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeCreateScheduleRequest body: (required)
        :return: RimeCreateScheduleResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.schedule_service_create_schedule_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.schedule_service_create_schedule_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def schedule_service_create_schedule_with_http_info(self, body, **kwargs):  # noqa: E501
        """CreateSchedule creates a schedule.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.schedule_service_create_schedule_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeCreateScheduleRequest body: (required)
        :return: RimeCreateScheduleResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method schedule_service_create_schedule" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `schedule_service_create_schedule`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/schedules', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeCreateScheduleResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def schedule_service_delete_schedule(self, schedule_id_uuid, **kwargs):  # noqa: E501
        """DeleteSchedule deletes a schedule.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.schedule_service_delete_schedule(schedule_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str schedule_id_uuid: Unique object ID. (required)
        :return: RimeDeleteScheduleResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.schedule_service_delete_schedule_with_http_info(schedule_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.schedule_service_delete_schedule_with_http_info(schedule_id_uuid, **kwargs)  # noqa: E501
            return data

    def schedule_service_delete_schedule_with_http_info(self, schedule_id_uuid, **kwargs):  # noqa: E501
        """DeleteSchedule deletes a schedule.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.schedule_service_delete_schedule_with_http_info(schedule_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str schedule_id_uuid: Unique object ID. (required)
        :return: RimeDeleteScheduleResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['schedule_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method schedule_service_delete_schedule" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'schedule_id_uuid' is set
        if ('schedule_id_uuid' not in params or
                params['schedule_id_uuid'] is None):
            raise ValueError("Missing the required parameter `schedule_id_uuid` when calling `schedule_service_delete_schedule`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'schedule_id_uuid' in params:
            path_params['scheduleId.uuid'] = params['schedule_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/schedules/{scheduleId.uuid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeDeleteScheduleResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def schedule_service_get_schedule(self, schedule_id_uuid, **kwargs):  # noqa: E501
        """GetSchedule gets a schedule.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.schedule_service_get_schedule(schedule_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str schedule_id_uuid: Unique object ID. (required)
        :return: RimeGetScheduleResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.schedule_service_get_schedule_with_http_info(schedule_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.schedule_service_get_schedule_with_http_info(schedule_id_uuid, **kwargs)  # noqa: E501
            return data

    def schedule_service_get_schedule_with_http_info(self, schedule_id_uuid, **kwargs):  # noqa: E501
        """GetSchedule gets a schedule.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.schedule_service_get_schedule_with_http_info(schedule_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str schedule_id_uuid: Unique object ID. (required)
        :return: RimeGetScheduleResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['schedule_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method schedule_service_get_schedule" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'schedule_id_uuid' is set
        if ('schedule_id_uuid' not in params or
                params['schedule_id_uuid'] is None):
            raise ValueError("Missing the required parameter `schedule_id_uuid` when calling `schedule_service_get_schedule`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'schedule_id_uuid' in params:
            path_params['scheduleId.uuid'] = params['schedule_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/schedules/{scheduleId.uuid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeGetScheduleResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def schedule_service_update_schedule(self, body, mask, schedule_schedule_id_uuid, **kwargs):  # noqa: E501
        """UpdateSchedule updates a schedule.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.schedule_service_update_schedule(body, mask, schedule_schedule_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SchedulesScheduleScheduleIdUuidBody body: (required)
        :param str mask: Update mask specifies the fields in the config that will be updated. Any values not in the mask will be ignored. Currently only updated the frequency of the schedule is supported. (required)
        :param str schedule_schedule_id_uuid: Unique object ID. (required)
        :return: RimeUpdateScheduleResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.schedule_service_update_schedule_with_http_info(body, mask, schedule_schedule_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.schedule_service_update_schedule_with_http_info(body, mask, schedule_schedule_id_uuid, **kwargs)  # noqa: E501
            return data

    def schedule_service_update_schedule_with_http_info(self, body, mask, schedule_schedule_id_uuid, **kwargs):  # noqa: E501
        """UpdateSchedule updates a schedule.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.schedule_service_update_schedule_with_http_info(body, mask, schedule_schedule_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SchedulesScheduleScheduleIdUuidBody body: (required)
        :param str mask: Update mask specifies the fields in the config that will be updated. Any values not in the mask will be ignored. Currently only updated the frequency of the schedule is supported. (required)
        :param str schedule_schedule_id_uuid: Unique object ID. (required)
        :return: RimeUpdateScheduleResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'mask', 'schedule_schedule_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method schedule_service_update_schedule" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `schedule_service_update_schedule`")  # noqa: E501
        # verify the required parameter 'mask' is set
        if ('mask' not in params or
                params['mask'] is None):
            raise ValueError("Missing the required parameter `mask` when calling `schedule_service_update_schedule`")  # noqa: E501
        # verify the required parameter 'schedule_schedule_id_uuid' is set
        if ('schedule_schedule_id_uuid' not in params or
                params['schedule_schedule_id_uuid'] is None):
            raise ValueError("Missing the required parameter `schedule_schedule_id_uuid` when calling `schedule_service_update_schedule`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'schedule_schedule_id_uuid' in params:
            path_params['schedule.scheduleId.uuid'] = params['schedule_schedule_id_uuid']  # noqa: E501

        query_params = []
        if 'mask' in params:
            query_params.append(('mask', params['mask']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/schedules/{schedule.scheduleId.uuid}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeUpdateScheduleResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from rime_sdk.swagger.swagger_client.api_client import ApiClient


class AgentManagerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def agent_manager_create_agent(self, body, **kwargs):  # noqa: E501
        """CreateAgent  # noqa: E501

        Creates agent and returns the configuration for installing the agent.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_create_agent(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeCreateAgentRequest body: (required)
        :return: RimeCreateAgentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_manager_create_agent_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_manager_create_agent_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def agent_manager_create_agent_with_http_info(self, body, **kwargs):  # noqa: E501
        """CreateAgent  # noqa: E501

        Creates agent and returns the configuration for installing the agent.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_create_agent_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeCreateAgentRequest body: (required)
        :return: RimeCreateAgentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_manager_create_agent" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `agent_manager_create_agent`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/agents', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeCreateAgentResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_manager_create_firewall_agent(self, body, **kwargs):  # noqa: E501
        """CreateFirewallAgent  # noqa: E501

        Creates a firewall agent and returns the api key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_create_firewall_agent(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeCreateFirewallAgentRequest body: (required)
        :return: RimeCreateFirewallAgentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_manager_create_firewall_agent_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_manager_create_firewall_agent_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def agent_manager_create_firewall_agent_with_http_info(self, body, **kwargs):  # noqa: E501
        """CreateFirewallAgent  # noqa: E501

        Creates a firewall agent and returns the api key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_create_firewall_agent_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeCreateFirewallAgentRequest body: (required)
        :return: RimeCreateFirewallAgentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_manager_create_firewall_agent" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `agent_manager_create_firewall_agent`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/agents/firewall', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeCreateFirewallAgentResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_manager_create_firewall_instance(self, body, agent_id_uuid, **kwargs):  # noqa: E501
        """CreateFirewallInstance  # noqa: E501

        Creates a new firewall instance record in the DB. It does not directly deploy the firewall instance in the agent.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_create_firewall_instance(body, agent_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateFirewallInstanceRequestIsTheRequestForCreateFirewallInstance body: (required)
        :param str agent_id_uuid: Unique object ID. (required)
        :return: RimeCreateFirewallInstanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_manager_create_firewall_instance_with_http_info(body, agent_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_manager_create_firewall_instance_with_http_info(body, agent_id_uuid, **kwargs)  # noqa: E501
            return data

    def agent_manager_create_firewall_instance_with_http_info(self, body, agent_id_uuid, **kwargs):  # noqa: E501
        """CreateFirewallInstance  # noqa: E501

        Creates a new firewall instance record in the DB. It does not directly deploy the firewall instance in the agent.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_create_firewall_instance_with_http_info(body, agent_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateFirewallInstanceRequestIsTheRequestForCreateFirewallInstance body: (required)
        :param str agent_id_uuid: Unique object ID. (required)
        :return: RimeCreateFirewallInstanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'agent_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_manager_create_firewall_instance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `agent_manager_create_firewall_instance`")  # noqa: E501
        # verify the required parameter 'agent_id_uuid' is set
        if ('agent_id_uuid' not in params or
                params['agent_id_uuid'] is None):
            raise ValueError("Missing the required parameter `agent_id_uuid` when calling `agent_manager_create_firewall_instance`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'agent_id_uuid' in params:
            path_params['agentId.uuid'] = params['agent_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/internal/agents/firewall/{agentId.uuid}/firewall-instance', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeCreateFirewallInstanceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_manager_delete_agent(self, agent_id_uuid, **kwargs):  # noqa: E501
        """DeleteAgent  # noqa: E501

        Deletes a specified agent. Must be called on an already deactivated agent. An error is returned if the deletion fails or if the agent is not in a deletable state.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_delete_agent(agent_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str agent_id_uuid: Unique object ID. (required)
        :return: RimeDeleteAgentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_manager_delete_agent_with_http_info(agent_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_manager_delete_agent_with_http_info(agent_id_uuid, **kwargs)  # noqa: E501
            return data

    def agent_manager_delete_agent_with_http_info(self, agent_id_uuid, **kwargs):  # noqa: E501
        """DeleteAgent  # noqa: E501

        Deletes a specified agent. Must be called on an already deactivated agent. An error is returned if the deletion fails or if the agent is not in a deletable state.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_delete_agent_with_http_info(agent_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str agent_id_uuid: Unique object ID. (required)
        :return: RimeDeleteAgentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['agent_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_manager_delete_agent" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'agent_id_uuid' is set
        if ('agent_id_uuid' not in params or
                params['agent_id_uuid'] is None):
            raise ValueError("Missing the required parameter `agent_id_uuid` when calling `agent_manager_delete_agent`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'agent_id_uuid' in params:
            path_params['agentId.uuid'] = params['agent_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/agents/{agentId.uuid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeDeleteAgentResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_manager_delete_firewall_instance(self, agent_id_uuid, firewall_instance_id_uuid, **kwargs):  # noqa: E501
        """DeleteFirewallInstance  # noqa: E501

        Deletes the firewall instance from the DB. It does not directly impact the deployment of the firewall instance in the agent.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_delete_firewall_instance(agent_id_uuid, firewall_instance_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str agent_id_uuid: Unique object ID. (required)
        :param str firewall_instance_id_uuid: Unique object ID. (required)
        :return: RimeDeleteFirewallInstanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_manager_delete_firewall_instance_with_http_info(agent_id_uuid, firewall_instance_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_manager_delete_firewall_instance_with_http_info(agent_id_uuid, firewall_instance_id_uuid, **kwargs)  # noqa: E501
            return data

    def agent_manager_delete_firewall_instance_with_http_info(self, agent_id_uuid, firewall_instance_id_uuid, **kwargs):  # noqa: E501
        """DeleteFirewallInstance  # noqa: E501

        Deletes the firewall instance from the DB. It does not directly impact the deployment of the firewall instance in the agent.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_delete_firewall_instance_with_http_info(agent_id_uuid, firewall_instance_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str agent_id_uuid: Unique object ID. (required)
        :param str firewall_instance_id_uuid: Unique object ID. (required)
        :return: RimeDeleteFirewallInstanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['agent_id_uuid', 'firewall_instance_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_manager_delete_firewall_instance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'agent_id_uuid' is set
        if ('agent_id_uuid' not in params or
                params['agent_id_uuid'] is None):
            raise ValueError("Missing the required parameter `agent_id_uuid` when calling `agent_manager_delete_firewall_instance`")  # noqa: E501
        # verify the required parameter 'firewall_instance_id_uuid' is set
        if ('firewall_instance_id_uuid' not in params or
                params['firewall_instance_id_uuid'] is None):
            raise ValueError("Missing the required parameter `firewall_instance_id_uuid` when calling `agent_manager_delete_firewall_instance`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'agent_id_uuid' in params:
            path_params['agentId.uuid'] = params['agent_id_uuid']  # noqa: E501
        if 'firewall_instance_id_uuid' in params:
            path_params['firewallInstanceId.uuid'] = params['firewall_instance_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/internal/agents/firewall/{agentId.uuid}/firewall-instance/{firewallInstanceId.uuid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeDeleteFirewallInstanceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_manager_firewall_instance_heartbeat(self, body, agent_id_uuid, firewall_instance_id_uuid, **kwargs):  # noqa: E501
        """FirewallInstanceHeartbeat accepts heartbeat signals from firewall instances. This allows us to confirm that the firewall instance is still running.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_firewall_instance_heartbeat(body, agent_id_uuid, firewall_instance_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FirewallInstanceIdUuidHeartbeatBody body: (required)
        :param str agent_id_uuid: Unique object ID. (required)
        :param str firewall_instance_id_uuid: Unique object ID. (required)
        :return: RimeFirewallInstanceHeartbeatResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_manager_firewall_instance_heartbeat_with_http_info(body, agent_id_uuid, firewall_instance_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_manager_firewall_instance_heartbeat_with_http_info(body, agent_id_uuid, firewall_instance_id_uuid, **kwargs)  # noqa: E501
            return data

    def agent_manager_firewall_instance_heartbeat_with_http_info(self, body, agent_id_uuid, firewall_instance_id_uuid, **kwargs):  # noqa: E501
        """FirewallInstanceHeartbeat accepts heartbeat signals from firewall instances. This allows us to confirm that the firewall instance is still running.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_firewall_instance_heartbeat_with_http_info(body, agent_id_uuid, firewall_instance_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FirewallInstanceIdUuidHeartbeatBody body: (required)
        :param str agent_id_uuid: Unique object ID. (required)
        :param str firewall_instance_id_uuid: Unique object ID. (required)
        :return: RimeFirewallInstanceHeartbeatResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'agent_id_uuid', 'firewall_instance_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_manager_firewall_instance_heartbeat" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `agent_manager_firewall_instance_heartbeat`")  # noqa: E501
        # verify the required parameter 'agent_id_uuid' is set
        if ('agent_id_uuid' not in params or
                params['agent_id_uuid'] is None):
            raise ValueError("Missing the required parameter `agent_id_uuid` when calling `agent_manager_firewall_instance_heartbeat`")  # noqa: E501
        # verify the required parameter 'firewall_instance_id_uuid' is set
        if ('firewall_instance_id_uuid' not in params or
                params['firewall_instance_id_uuid'] is None):
            raise ValueError("Missing the required parameter `firewall_instance_id_uuid` when calling `agent_manager_firewall_instance_heartbeat`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'agent_id_uuid' in params:
            path_params['agentId.uuid'] = params['agent_id_uuid']  # noqa: E501
        if 'firewall_instance_id_uuid' in params:
            path_params['firewallInstanceId.uuid'] = params['firewall_instance_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/internal/agents/firewall/{agentId.uuid}/firewall-instance/{firewallInstanceId.uuid}/heartbeat', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeFirewallInstanceHeartbeatResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_manager_get_agent(self, agent_id_uuid, **kwargs):  # noqa: E501
        """GetAgent  # noqa: E501

        Returns the agent that matches the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_get_agent(agent_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str agent_id_uuid: Unique object ID. (required)
        :return: RimeGetAgentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_manager_get_agent_with_http_info(agent_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_manager_get_agent_with_http_info(agent_id_uuid, **kwargs)  # noqa: E501
            return data

    def agent_manager_get_agent_with_http_info(self, agent_id_uuid, **kwargs):  # noqa: E501
        """GetAgent  # noqa: E501

        Returns the agent that matches the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_get_agent_with_http_info(agent_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str agent_id_uuid: Unique object ID. (required)
        :return: RimeGetAgentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['agent_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_manager_get_agent" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'agent_id_uuid' is set
        if ('agent_id_uuid' not in params or
                params['agent_id_uuid'] is None):
            raise ValueError("Missing the required parameter `agent_id_uuid` when calling `agent_manager_get_agent`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'agent_id_uuid' in params:
            path_params['agentId.uuid'] = params['agent_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/agents/{agentId.uuid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeGetAgentResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_manager_get_upgrade_for_agent(self, agent_id_uuid, agent_namespace, **kwargs):  # noqa: E501
        """GetUpgradeForAgent returns the desired state of the agent and the current status of the upgrade.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_get_upgrade_for_agent(agent_id_uuid, agent_namespace, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str agent_id_uuid: Unique object ID. (required)
        :param str agent_namespace: The namespace in which the agent is deployed. Since namespace is not known in the CP, it must be provided by the launcher when calling GetUpgradeForAgent. (required)
        :param bool return_rendered_manifests: Whether to render and return the Kubernetes manifests
        :return: RimeGetUpgradeForAgentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_manager_get_upgrade_for_agent_with_http_info(agent_id_uuid, agent_namespace, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_manager_get_upgrade_for_agent_with_http_info(agent_id_uuid, agent_namespace, **kwargs)  # noqa: E501
            return data

    def agent_manager_get_upgrade_for_agent_with_http_info(self, agent_id_uuid, agent_namespace, **kwargs):  # noqa: E501
        """GetUpgradeForAgent returns the desired state of the agent and the current status of the upgrade.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_get_upgrade_for_agent_with_http_info(agent_id_uuid, agent_namespace, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str agent_id_uuid: Unique object ID. (required)
        :param str agent_namespace: The namespace in which the agent is deployed. Since namespace is not known in the CP, it must be provided by the launcher when calling GetUpgradeForAgent. (required)
        :param bool return_rendered_manifests: Whether to render and return the Kubernetes manifests
        :return: RimeGetUpgradeForAgentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['agent_id_uuid', 'agent_namespace', 'return_rendered_manifests']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_manager_get_upgrade_for_agent" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'agent_id_uuid' is set
        if ('agent_id_uuid' not in params or
                params['agent_id_uuid'] is None):
            raise ValueError("Missing the required parameter `agent_id_uuid` when calling `agent_manager_get_upgrade_for_agent`")  # noqa: E501
        # verify the required parameter 'agent_namespace' is set
        if ('agent_namespace' not in params or
                params['agent_namespace'] is None):
            raise ValueError("Missing the required parameter `agent_namespace` when calling `agent_manager_get_upgrade_for_agent`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'agent_id_uuid' in params:
            path_params['agentId.uuid'] = params['agent_id_uuid']  # noqa: E501

        query_params = []
        if 'return_rendered_manifests' in params:
            query_params.append(('returnRenderedManifests', params['return_rendered_manifests']))  # noqa: E501
        if 'agent_namespace' in params:
            query_params.append(('agentNamespace', params['agent_namespace']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/agents/{agentId.uuid}/upgrade', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeGetUpgradeForAgentResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_manager_heartbeat(self, body, agent_id_uuid, **kwargs):  # noqa: E501
        """Heartbeat accepts heartbeat signal from agent indicating that they are still running.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_heartbeat(body, agent_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param HeartbeatAgentIdUuidBody body: (required)
        :param str agent_id_uuid: Unique object ID. (required)
        :return: RimeHeartbeatResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_manager_heartbeat_with_http_info(body, agent_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_manager_heartbeat_with_http_info(body, agent_id_uuid, **kwargs)  # noqa: E501
            return data

    def agent_manager_heartbeat_with_http_info(self, body, agent_id_uuid, **kwargs):  # noqa: E501
        """Heartbeat accepts heartbeat signal from agent indicating that they are still running.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_heartbeat_with_http_info(body, agent_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param HeartbeatAgentIdUuidBody body: (required)
        :param str agent_id_uuid: Unique object ID. (required)
        :return: RimeHeartbeatResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'agent_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_manager_heartbeat" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `agent_manager_heartbeat`")  # noqa: E501
        # verify the required parameter 'agent_id_uuid' is set
        if ('agent_id_uuid' not in params or
                params['agent_id_uuid'] is None):
            raise ValueError("Missing the required parameter `agent_id_uuid` when calling `agent_manager_heartbeat`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'agent_id_uuid' in params:
            path_params['agentId.uuid'] = params['agent_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/internal/agents/heartbeat/{agentId.uuid}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeHeartbeatResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_manager_list_agents(self, **kwargs):  # noqa: E501
        """ListAgents  # noqa: E501

        Returns a paginated list of agents.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_list_agents(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str page_size: The maximum number of Agent objects to return in a single page.
        :param str page_token: Specifies a page of the list returned by a ListAgents query. The ListAgents query returns a pageToken when there is more than one page of results. Specify either this field or the firstPageQuery field.
        :param list[str] first_page_query_agent_status_types: Specifies a set of agent status types. The query filters for results that match the specified types.   - AGENT_STATUS_PENDING: Resources have been created for the agent but the agent has not started yet.  - AGENT_STATUS_ACTIVE: Agent can run jobs.  - AGENT_STATUS_UNRESPONSIVE: No agent heartbeat for three minutes.  - AGENT_STATUS_DEACTIVATED: Agent can no longer run jobs and can be deleted. (Deprecated after Deactivation and Deletion endpoints are combined)
        :param list[str] first_page_query_agent_ids: Specifies a set of agent IDs. The query filters for results that match the specified IDs.
        :param str first_page_query_type: Specifies the type of agent (validation or firewall). The query filters for results that match the specified type.   - AGENT_TYPE_VALIDATION: We use the zero value for VALIDATION for backwards compatibility with existing agents. protolint:disable:next ENUM_FIELD_NAMES_ZERO_VALUE_END_WITH
        :return: RimeListAgentsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_manager_list_agents_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.agent_manager_list_agents_with_http_info(**kwargs)  # noqa: E501
            return data

    def agent_manager_list_agents_with_http_info(self, **kwargs):  # noqa: E501
        """ListAgents  # noqa: E501

        Returns a paginated list of agents.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_list_agents_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str page_size: The maximum number of Agent objects to return in a single page.
        :param str page_token: Specifies a page of the list returned by a ListAgents query. The ListAgents query returns a pageToken when there is more than one page of results. Specify either this field or the firstPageQuery field.
        :param list[str] first_page_query_agent_status_types: Specifies a set of agent status types. The query filters for results that match the specified types.   - AGENT_STATUS_PENDING: Resources have been created for the agent but the agent has not started yet.  - AGENT_STATUS_ACTIVE: Agent can run jobs.  - AGENT_STATUS_UNRESPONSIVE: No agent heartbeat for three minutes.  - AGENT_STATUS_DEACTIVATED: Agent can no longer run jobs and can be deleted. (Deprecated after Deactivation and Deletion endpoints are combined)
        :param list[str] first_page_query_agent_ids: Specifies a set of agent IDs. The query filters for results that match the specified IDs.
        :param str first_page_query_type: Specifies the type of agent (validation or firewall). The query filters for results that match the specified type.   - AGENT_TYPE_VALIDATION: We use the zero value for VALIDATION for backwards compatibility with existing agents. protolint:disable:next ENUM_FIELD_NAMES_ZERO_VALUE_END_WITH
        :return: RimeListAgentsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page_token', 'first_page_query_agent_status_types', 'first_page_query_agent_ids', 'first_page_query_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_manager_list_agents" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'first_page_query_agent_status_types' in params:
            query_params.append(('firstPageQuery.agentStatusTypes', params['first_page_query_agent_status_types']))  # noqa: E501
            collection_formats['firstPageQuery.agentStatusTypes'] = 'multi'  # noqa: E501
        if 'first_page_query_agent_ids' in params:
            query_params.append(('firstPageQuery.agentIds', params['first_page_query_agent_ids']))  # noqa: E501
            collection_formats['firstPageQuery.agentIds'] = 'multi'  # noqa: E501
        if 'first_page_query_type' in params:
            query_params.append(('firstPageQuery.type', params['first_page_query_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/agents', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeListAgentsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_manager_list_firewall_instances(self, **kwargs):  # noqa: E501
        """ListFirewallInstances  # noqa: E501

        Returns a paginated list of firewall instances.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_list_firewall_instances(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str page_size:
        :param str page_token: Specifies a page of the list returned by a ListFirewallInstances query. The ListFirewallInstances query returns a pageToken when there is more than one page of results. Specify either this field or the firstPageQuery field.
        :param list[str] first_page_query_agent_ids: Specifies a set of agent IDs. The query filters for firewall instances that belong to the specified agents.
        :return: RimeListFirewallInstancesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_manager_list_firewall_instances_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.agent_manager_list_firewall_instances_with_http_info(**kwargs)  # noqa: E501
            return data

    def agent_manager_list_firewall_instances_with_http_info(self, **kwargs):  # noqa: E501
        """ListFirewallInstances  # noqa: E501

        Returns a paginated list of firewall instances.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_list_firewall_instances_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str page_size:
        :param str page_token: Specifies a page of the list returned by a ListFirewallInstances query. The ListFirewallInstances query returns a pageToken when there is more than one page of results. Specify either this field or the firstPageQuery field.
        :param list[str] first_page_query_agent_ids: Specifies a set of agent IDs. The query filters for firewall instances that belong to the specified agents.
        :return: RimeListFirewallInstancesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page_token', 'first_page_query_agent_ids']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_manager_list_firewall_instances" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'first_page_query_agent_ids' in params:
            query_params.append(('firstPageQuery.agentIds', params['first_page_query_agent_ids']))  # noqa: E501
            collection_formats['firstPageQuery.agentIds'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/agents/firewall/instances', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeListFirewallInstancesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_manager_register_external_agent(self, body, **kwargs):  # noqa: E501
        """RegisterExternalAgent is used by external agents during startup to upload the signing key to the backend. This call is idempotent; it will be called by the external agent upon every restart. No matter there is a signing key exists in the DB, the key is uploaded and created in the DB.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_register_external_agent(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeRegisterExternalAgentRequest body: (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_manager_register_external_agent_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_manager_register_external_agent_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def agent_manager_register_external_agent_with_http_info(self, body, **kwargs):  # noqa: E501
        """RegisterExternalAgent is used by external agents during startup to upload the signing key to the backend. This call is idempotent; it will be called by the external agent upon every restart. No matter there is a signing key exists in the DB, the key is uploaded and created in the DB.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_register_external_agent_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeRegisterExternalAgentRequest body: (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_manager_register_external_agent" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `agent_manager_register_external_agent`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/internal/agents/external', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_manager_register_firewall_agent(self, body, **kwargs):  # noqa: E501
        """RegisterFirewallAgent is used by firewall agents during startup to upload the signing key to the CP backend. In addtion, the CP will return a public key that is used to verify user API tokens.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_register_firewall_agent(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeRegisterFirewallAgentRequest body: (required)
        :return: RimeRegisterFirewallAgentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_manager_register_firewall_agent_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_manager_register_firewall_agent_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def agent_manager_register_firewall_agent_with_http_info(self, body, **kwargs):  # noqa: E501
        """RegisterFirewallAgent is used by firewall agents during startup to upload the signing key to the CP backend. In addtion, the CP will return a public key that is used to verify user API tokens.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_register_firewall_agent_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeRegisterFirewallAgentRequest body: (required)
        :return: RimeRegisterFirewallAgentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_manager_register_firewall_agent" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `agent_manager_register_firewall_agent`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/internal/agents/firewall', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeRegisterFirewallAgentResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_manager_update_upgrade_status_for_agent(self, body, agent_id_uuid, **kwargs):  # noqa: E501
        """UpdateUpgradeStatusForAgent updates the status of the upgrade for the agent.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_update_upgrade_status_for_agent(body, agent_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AgentIdUuidUpgradeBody body: (required)
        :param str agent_id_uuid: Unique object ID. (required)
        :return: RimeUpdateUpgradeStatusForAgentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_manager_update_upgrade_status_for_agent_with_http_info(body, agent_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_manager_update_upgrade_status_for_agent_with_http_info(body, agent_id_uuid, **kwargs)  # noqa: E501
            return data

    def agent_manager_update_upgrade_status_for_agent_with_http_info(self, body, agent_id_uuid, **kwargs):  # noqa: E501
        """UpdateUpgradeStatusForAgent updates the status of the upgrade for the agent.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_update_upgrade_status_for_agent_with_http_info(body, agent_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AgentIdUuidUpgradeBody body: (required)
        :param str agent_id_uuid: Unique object ID. (required)
        :return: RimeUpdateUpgradeStatusForAgentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'agent_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_manager_update_upgrade_status_for_agent" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `agent_manager_update_upgrade_status_for_agent`")  # noqa: E501
        # verify the required parameter 'agent_id_uuid' is set
        if ('agent_id_uuid' not in params or
                params['agent_id_uuid'] is None):
            raise ValueError("Missing the required parameter `agent_id_uuid` when calling `agent_manager_update_upgrade_status_for_agent`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'agent_id_uuid' in params:
            path_params['agentId.uuid'] = params['agent_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/internal/agents/{agentId.uuid}/upgrade', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeUpdateUpgradeStatusForAgentResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_manager_upgrade_agent(self, body, agent_id_uuid, **kwargs):  # noqa: E501
        """UpgradeAgent starts the process of upgrading the agent to the version of the control plane  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_upgrade_agent(body, agent_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AgentIdUuidUpgradeBody1 body: (required)
        :param str agent_id_uuid: Unique object ID. (required)
        :return: RimeUpgradeAgentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_manager_upgrade_agent_with_http_info(body, agent_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_manager_upgrade_agent_with_http_info(body, agent_id_uuid, **kwargs)  # noqa: E501
            return data

    def agent_manager_upgrade_agent_with_http_info(self, body, agent_id_uuid, **kwargs):  # noqa: E501
        """UpgradeAgent starts the process of upgrading the agent to the version of the control plane  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_manager_upgrade_agent_with_http_info(body, agent_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AgentIdUuidUpgradeBody1 body: (required)
        :param str agent_id_uuid: Unique object ID. (required)
        :return: RimeUpgradeAgentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'agent_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_manager_upgrade_agent" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `agent_manager_upgrade_agent`")  # noqa: E501
        # verify the required parameter 'agent_id_uuid' is set
        if ('agent_id_uuid' not in params or
                params['agent_id_uuid'] is None):
            raise ValueError("Missing the required parameter `agent_id_uuid` when calling `agent_manager_upgrade_agent`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'agent_id_uuid' in params:
            path_params['agentId.uuid'] = params['agent_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/agents/{agentId.uuid}/upgrade', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeUpgradeAgentResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CustommonitorsNameBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'firewall_id': 'RimeUUID',
        'artifact_identifier': 'MonitorArtifactIdentifier',
        'aggregation': 'MonitorAggregation',
        'transform': 'MonitorTransform',
        'threshold': 'MonitorThreshold',
        'notify': 'bool'
    }

    attribute_map = {
        'firewall_id': 'firewallId',
        'artifact_identifier': 'artifactIdentifier',
        'aggregation': 'aggregation',
        'transform': 'transform',
        'threshold': 'threshold',
        'notify': 'notify'
    }

    def __init__(self, firewall_id=None, artifact_identifier=None, aggregation=None, transform=None, threshold=None, notify=None):  # noqa: E501
        """CustommonitorsNameBody - a model defined in Swagger"""  # noqa: E501
        self._firewall_id = None
        self._artifact_identifier = None
        self._aggregation = None
        self._transform = None
        self._threshold = None
        self._notify = None
        self.discriminator = None
        if firewall_id is not None:
            self.firewall_id = firewall_id
        if artifact_identifier is not None:
            self.artifact_identifier = artifact_identifier
        if aggregation is not None:
            self.aggregation = aggregation
        if transform is not None:
            self.transform = transform
        if threshold is not None:
            self.threshold = threshold
        if notify is not None:
            self.notify = notify

    @property
    def firewall_id(self):
        """Gets the firewall_id of this CustommonitorsNameBody.  # noqa: E501


        :return: The firewall_id of this CustommonitorsNameBody.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._firewall_id

    @firewall_id.setter
    def firewall_id(self, firewall_id):
        """Sets the firewall_id of this CustommonitorsNameBody.


        :param firewall_id: The firewall_id of this CustommonitorsNameBody.  # noqa: E501
        :type: RimeUUID
        """

        self._firewall_id = firewall_id

    @property
    def artifact_identifier(self):
        """Gets the artifact_identifier of this CustommonitorsNameBody.  # noqa: E501


        :return: The artifact_identifier of this CustommonitorsNameBody.  # noqa: E501
        :rtype: MonitorArtifactIdentifier
        """
        return self._artifact_identifier

    @artifact_identifier.setter
    def artifact_identifier(self, artifact_identifier):
        """Sets the artifact_identifier of this CustommonitorsNameBody.


        :param artifact_identifier: The artifact_identifier of this CustommonitorsNameBody.  # noqa: E501
        :type: MonitorArtifactIdentifier
        """

        self._artifact_identifier = artifact_identifier

    @property
    def aggregation(self):
        """Gets the aggregation of this CustommonitorsNameBody.  # noqa: E501


        :return: The aggregation of this CustommonitorsNameBody.  # noqa: E501
        :rtype: MonitorAggregation
        """
        return self._aggregation

    @aggregation.setter
    def aggregation(self, aggregation):
        """Sets the aggregation of this CustommonitorsNameBody.


        :param aggregation: The aggregation of this CustommonitorsNameBody.  # noqa: E501
        :type: MonitorAggregation
        """

        self._aggregation = aggregation

    @property
    def transform(self):
        """Gets the transform of this CustommonitorsNameBody.  # noqa: E501


        :return: The transform of this CustommonitorsNameBody.  # noqa: E501
        :rtype: MonitorTransform
        """
        return self._transform

    @transform.setter
    def transform(self, transform):
        """Sets the transform of this CustommonitorsNameBody.


        :param transform: The transform of this CustommonitorsNameBody.  # noqa: E501
        :type: MonitorTransform
        """

        self._transform = transform

    @property
    def threshold(self):
        """Gets the threshold of this CustommonitorsNameBody.  # noqa: E501


        :return: The threshold of this CustommonitorsNameBody.  # noqa: E501
        :rtype: MonitorThreshold
        """
        return self._threshold

    @threshold.setter
    def threshold(self, threshold):
        """Sets the threshold of this CustommonitorsNameBody.


        :param threshold: The threshold of this CustommonitorsNameBody.  # noqa: E501
        :type: MonitorThreshold
        """

        self._threshold = threshold

    @property
    def notify(self):
        """Gets the notify of this CustommonitorsNameBody.  # noqa: E501

        Whether to notify when the monitor is triggered.  # noqa: E501

        :return: The notify of this CustommonitorsNameBody.  # noqa: E501
        :rtype: bool
        """
        return self._notify

    @notify.setter
    def notify(self, notify):
        """Sets the notify of this CustommonitorsNameBody.

        Whether to notify when the monitor is triggered.  # noqa: E501

        :param notify: The notify of this CustommonitorsNameBody.  # noqa: E501
        :type: bool
        """

        self._notify = notify

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CustommonitorsNameBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustommonitorsNameBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from rime_sdk.swagger.swagger_client.api_client import ApiClient


class ImageRegistryApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def image_registry_create_image(self, body, **kwargs):  # noqa: E501
        """CreateImage  # noqa: E501

        Creates a new Managed Image with a unique name.  Managed images are not currently supported in a Cloud deployment. Please reach out to Robust Intelligence for support if this functionality is required for your deployment.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.image_registry_create_image(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeCreateImageRequest body: (required)
        :return: RimeCreateImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.image_registry_create_image_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.image_registry_create_image_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def image_registry_create_image_with_http_info(self, body, **kwargs):  # noqa: E501
        """CreateImage  # noqa: E501

        Creates a new Managed Image with a unique name.  Managed images are not currently supported in a Cloud deployment. Please reach out to Robust Intelligence for support if this functionality is required for your deployment.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.image_registry_create_image_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeCreateImageRequest body: (required)
        :return: RimeCreateImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method image_registry_create_image" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `image_registry_create_image`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/images', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeCreateImageResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def image_registry_delete_image(self, name, **kwargs):  # noqa: E501
        """DeleteImage  # noqa: E501

        Deletes a specified Managed Image.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.image_registry_delete_image(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: Name of existing Managed Image to delete. (required)
        :return: RimeDeleteImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.image_registry_delete_image_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.image_registry_delete_image_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def image_registry_delete_image_with_http_info(self, name, **kwargs):  # noqa: E501
        """DeleteImage  # noqa: E501

        Deletes a specified Managed Image.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.image_registry_delete_image_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: Name of existing Managed Image to delete. (required)
        :return: RimeDeleteImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method image_registry_delete_image" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `image_registry_delete_image`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/images/{name}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeDeleteImageResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def image_registry_get_image(self, name, **kwargs):  # noqa: E501
        """GetImage  # noqa: E501

        Returns the definition of a specified Managed Image.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.image_registry_get_image(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: Name of the existing Managed Image. (required)
        :return: RimeGetImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.image_registry_get_image_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.image_registry_get_image_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def image_registry_get_image_with_http_info(self, name, **kwargs):  # noqa: E501
        """GetImage  # noqa: E501

        Returns the definition of a specified Managed Image.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.image_registry_get_image_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: Name of the existing Managed Image. (required)
        :return: RimeGetImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method image_registry_get_image" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `image_registry_get_image`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/images/{name}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeGetImageResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def image_registry_list_images(self, **kwargs):  # noqa: E501
        """ListImages  # noqa: E501

        List all Managed Images that match a specified set of constraints.  #### Python pagination example:  ```python all_objects = [] # Required for authentication to all methods in the API. headers = {\"rime-api-key\": \"INSERT_API_TOKEN\"} # TODO page_token = \"\" # Initialize query parameters in a dictionary params = {\"INSERT_QUERY_PARAMETER\": \"INSERT_QUERY_VALUE\"} # TODO # Make requests until all results have been returned. while True:     # If the page_token from a previous response is not empty, we need to specify this     # token as a parameter to the next request in order to return the next page.     if page_token != \"\":         params = {\"page_token\": page_token}     res = requests.get(\"INSERT_METHOD_URI\", params=params, headers=headers) # TODO     if res.status_code != 200 :         raise ValueError(res)     res_json = res.json()     all_objects.extend(res_json['INSERT_OBJECT_KEY']) # TODO     page_token = res_json['nextPageToken']     # If all results have been returned, res_json['hasMore'] is false.     if not res_json[\"hasMore\"]:         break ```  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.image_registry_list_images(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str page_token: Specifies a page of the list returned by a ListImages query. The ListImages query returns a pageToken when there is more than one page of results.
        :param str page_size: The maximum number of Image objects to return in a single page.
        :return: RimeListImagesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.image_registry_list_images_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.image_registry_list_images_with_http_info(**kwargs)  # noqa: E501
            return data

    def image_registry_list_images_with_http_info(self, **kwargs):  # noqa: E501
        """ListImages  # noqa: E501

        List all Managed Images that match a specified set of constraints.  #### Python pagination example:  ```python all_objects = [] # Required for authentication to all methods in the API. headers = {\"rime-api-key\": \"INSERT_API_TOKEN\"} # TODO page_token = \"\" # Initialize query parameters in a dictionary params = {\"INSERT_QUERY_PARAMETER\": \"INSERT_QUERY_VALUE\"} # TODO # Make requests until all results have been returned. while True:     # If the page_token from a previous response is not empty, we need to specify this     # token as a parameter to the next request in order to return the next page.     if page_token != \"\":         params = {\"page_token\": page_token}     res = requests.get(\"INSERT_METHOD_URI\", params=params, headers=headers) # TODO     if res.status_code != 200 :         raise ValueError(res)     res_json = res.json()     all_objects.extend(res_json['INSERT_OBJECT_KEY']) # TODO     page_token = res_json['nextPageToken']     # If all results have been returned, res_json['hasMore'] is false.     if not res_json[\"hasMore\"]:         break ```  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.image_registry_list_images_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str page_token: Specifies a page of the list returned by a ListImages query. The ListImages query returns a pageToken when there is more than one page of results.
        :param str page_size: The maximum number of Image objects to return in a single page.
        :return: RimeListImagesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_token', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method image_registry_list_images" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/images', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeListImagesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def image_registry_list_images2(self, body, **kwargs):  # noqa: E501
        """ListImages  # noqa: E501

        List all Managed Images that match a specified set of constraints.  #### Python pagination example:  ```python all_objects = [] # Required for authentication to all methods in the API. headers = {\"rime-api-key\": \"INSERT_API_TOKEN\"} # TODO page_token = \"\" # Initialize query parameters in a dictionary params = {\"INSERT_QUERY_PARAMETER\": \"INSERT_QUERY_VALUE\"} # TODO # Make requests until all results have been returned. while True:     # If the page_token from a previous response is not empty, we need to specify this     # token as a parameter to the next request in order to return the next page.     if page_token != \"\":         params = {\"page_token\": page_token}     res = requests.get(\"INSERT_METHOD_URI\", params=params, headers=headers) # TODO     if res.status_code != 200 :         raise ValueError(res)     res_json = res.json()     all_objects.extend(res_json['INSERT_OBJECT_KEY']) # TODO     page_token = res_json['nextPageToken']     # If all results have been returned, res_json['hasMore'] is false.     if not res_json[\"hasMore\"]:         break ```  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.image_registry_list_images2(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeListImagesRequest body: (required)
        :return: RimeListImagesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.image_registry_list_images2_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.image_registry_list_images2_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def image_registry_list_images2_with_http_info(self, body, **kwargs):  # noqa: E501
        """ListImages  # noqa: E501

        List all Managed Images that match a specified set of constraints.  #### Python pagination example:  ```python all_objects = [] # Required for authentication to all methods in the API. headers = {\"rime-api-key\": \"INSERT_API_TOKEN\"} # TODO page_token = \"\" # Initialize query parameters in a dictionary params = {\"INSERT_QUERY_PARAMETER\": \"INSERT_QUERY_VALUE\"} # TODO # Make requests until all results have been returned. while True:     # If the page_token from a previous response is not empty, we need to specify this     # token as a parameter to the next request in order to return the next page.     if page_token != \"\":         params = {\"page_token\": page_token}     res = requests.get(\"INSERT_METHOD_URI\", params=params, headers=headers) # TODO     if res.status_code != 200 :         raise ValueError(res)     res_json = res.json()     all_objects.extend(res_json['INSERT_OBJECT_KEY']) # TODO     page_token = res_json['nextPageToken']     # If all results have been returned, res_json['hasMore'] is false.     if not res_json[\"hasMore\"]:         break ```  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.image_registry_list_images2_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeListImagesRequest body: (required)
        :return: RimeListImagesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method image_registry_list_images2" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `image_registry_list_images2`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/images/list', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeListImagesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def image_registry_update_build_info(self, body, **kwargs):  # noqa: E501
        """UpdateBuildInfo updates the information about an image after an image build for it has completed.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.image_registry_update_build_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeUpdateBuildInfoRequest body: (required)
        :return: RimeUpdateBuildInfoResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.image_registry_update_build_info_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.image_registry_update_build_info_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def image_registry_update_build_info_with_http_info(self, body, **kwargs):  # noqa: E501
        """UpdateBuildInfo updates the information about an image after an image build for it has completed.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.image_registry_update_build_info_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeUpdateBuildInfoRequest body: (required)
        :return: RimeUpdateBuildInfoResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method image_registry_update_build_info" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `image_registry_update_build_info`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/internal/images/update-info', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeUpdateBuildInfoResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
